sherlockml
==========

.. image:: https://travis-ci.org/ASIDataScience/sherlockml.svg?branch=master
    :target: https://travis-ci.org/ASIDataScience/sherlockml

A Python library for interacting with `SherlockML <https://sherlockml.com/>`_.
